from distutils.core import setup

setup(name='aamoer',
      author='Thomas Levine',
      author_email='_@thomaslevine.com',
      description='Run statistics on data tables.',
      url='https://github.com/tlevine/aamoer',
      packages=['aamoer'],
      tests_require = ['nose'],
      version='0.0.1',
      license='AGPL',
)
